==> home-library-ftpclient-1.0.0-20160630.135206-19-sources.jar: org/gcube/common/homelibrary/client/servlet/Servlets.java <==
package org.gcube.common.homelibrary.client.servlet;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;
import java.util.List;
import java.util.Map;

import org.gcube.common.homelibrary.client.util.Config;
import org.gcube.common.homelibrary.client.util.MultipartUtility;

import com.thoughtworks.xstream.XStream;

public class Servlets {

	/**
	 * Get jackrabbit credentials
	 * @return a string with credentials
	 */
	public static String getCredentials() {
		String credentials = "adminId=" + Config.USERNAME + "&adminPassword=" + Config.PASSWORD;
		return credentials;
	}


	/**
	 * Delete files or folder
	 * @param absPath absolute path of the item to delete
	 * @return true if the file/folder has been deleted
	 * @throws Exception
	 */
	public static Boolean delete(String absPath) throws Exception{
		XStream xstream = null;
		String xmlOut = null;
		Boolean flag = false;
		try{
			String uri = Config.URL_REPOSITORY + "/post/Delete";
			String urlParameters = getCredentials() + "&login=" + Config.LOGIN + "&scope=" + Config.SCOPE + "&serviceName=" + Config.SERVICE_NAME+ "&absPath=" +  URLEncoder.encode(absPath, "UTF-8") ;
			URL url = new URL(uri);
			HttpURLConnection connection = (HttpURLConnection) url.openConnection();
			connection.setRequestMethod("POST");
			connection.setRequestProperty("Accept", "application/xml");

			// Send post request
			connection.setDoOutput(true);
			DataOutputStream wr = new DataOutputStream(connection.getOutputStream());
			wr.writeBytes(urlParameters);
			wr.flush();
			wr.close();

			int responseCode = connection.getResponseCode();
			//			System.out.println("\nSending 'POST' request to URL : " + url);
			//			System.out.println("Post parameters : " + urlParameters);
			System.out.println("Response Code : " + responseCode);

			xstream = new XStream();

			BufferedReader in = new BufferedReader(
					new InputStreamReader(connection.getInputStream()));

			StringBuffer response = new StringBuffer();
			String inputLine;
			while ((inputLine = in.readLine()) != null) {
				response.append(inputLine);
			}
			in.close();

			xmlOut = response.toString();

			connection.disconnect();


			flag = (Boolean) xstream.fromXML(xmlOut);


		} catch (ClassCastException e) {

			throw new Exception(e.getMessage());
		} 

		return flag;

	}
	
	
	
	/**
	 * Save a file
	 * @param in
	 * @param name
	 * @param description
	 * @param parentPath
	 * @param mimetype
	 * @param size
	 * @return
	 * @throws Exception
	 */
	public static String uploadFile(byte[] in, String name, String description, String parentPath, String mimetype, long size) throws Exception {
		XStream xstream = new XStream();

		System.out.println("Upload File " + name);

		String uri = Config.URL_REPOSITORY + "/post/Upload?" + getCredentials() + "&login=" + Config.LOGIN + "&scope=" + Config.SCOPE + "&serviceName=" + Config.SERVICE_NAME+ "&name=" + name+ "&description=" + URLEncoder.encode(description, "UTF-8") + "&parentPath=" + URLEncoder.encode(parentPath, "UTF-8") + "&mimetype=" + mimetype + "&size=" + String.valueOf(size);
		
		System.out.println(uri);
		URL url = new URL(uri);
		HttpURLConnection connection = (HttpURLConnection)url.openConnection();
		connection.setDoInput(true);
		connection.setDoOutput(true);
		connection.setUseCaches(false);
		connection.setRequestProperty("Content-Type", "image/jpeg");
		connection.setRequestMethod("POST");

		connection.getOutputStream().write(in);

		BufferedReader r = new BufferedReader(new  InputStreamReader(connection.getInputStream()));

		StringBuffer response = new StringBuffer();
		String inputLine;
		while ((inputLine = r.readLine()) != null) {
			response.append(inputLine);
		}

		String xmlOut = response.toString();
		return (String) xstream.fromXML(xmlOut);
	}



	/**
	 * Save a file
	 * @param path
	 * @param name
	 * @param description
	 * @param parentPath
	 * @return
	 * @throws Exception
	 */
	public static String uploadFile(File file, String name, String description, String parentPath, String charset) throws Exception {

		//		System.out.println("Save file " + name +  " in " + parentPath);

		StringBuffer res = new StringBuffer();
		XStream xstream = new XStream();
		try {

			if (name==null)
				name = file.getName();

			//			File uploadFile1 = new File(path);

			String requestURL = Config.URL_REPOSITORY + "/post/UploadFile?" + getCredentials() + "&login=" + Config.LOGIN + "&scope=" + Config.SCOPE + "&filename=" + file.getName()+ "&serviceName=" + Config.SERVICE_NAME+ "&name=" + name+ "&description=" + URLEncoder.encode(description, "UTF-8") + "&parentPath=" + URLEncoder.encode(parentPath, "UTF-8");
			MultipartUtility multipart = new MultipartUtility(requestURL, charset);

			multipart.addHeaderField("User-Agent", "CodeJava");
			multipart.addHeaderField("Test-Header", "Header-Value");

			multipart.addFormField("description", "upload file");
			//			multipart.addFormField("keywords", "Java,upload");

			multipart.addFilePart("fileUpload", file);
			//	            multipart.addFilePart("fileUpload", uploadFile2);

			List<String> response = multipart.finish();

			for (String line : response) {
				res.append(line);
			}

		} catch (IOException e) {
			throw new Exception(e.getMessage());
		} 

		return (String) xstream.fromXML(res.toString());
	}


	/**
	 * Create a folder
	 * @param name
	 * @param description
	 * @param parentPath
	 * @return
	 * @throws Exception
	 */
	public static String createFolder(String name, String description,
			String parentPath) throws Exception {

		System.out.println("Create Folder " + name);
		String uri = Config.URL_REPOSITORY + "/post/CreateFolder";
		String urlParameters = getCredentials() + "&login=" + Config.LOGIN + "&name=" + name+ "&description=" + URLEncoder.encode(description, "UTF-8") + "&parentPath=" + URLEncoder.encode(parentPath, "UTF-8");
		URL url = new URL(uri);
		HttpURLConnection connection = (HttpURLConnection) url.openConnection();
		connection.setRequestMethod("POST");
		connection.setRequestProperty("Accept", "application/xml");

		// Send post request
		connection.setDoOutput(true);
		DataOutputStream wr = new DataOutputStream(connection.getOutputStream());
		wr.writeBytes(urlParameters);
		wr.flush();
		wr.close();

		int responseCode = connection.getResponseCode();
		//		System.out.println("\nSending 'POST' request to URL : " + url);
		//		System.out.println("Post parameters : " + urlParameters);
		System.out.println("Response Code : " + responseCode);

		XStream xstream = new XStream();

		BufferedReader in = new BufferedReader(
				new InputStreamReader(connection.getInputStream()));

		StringBuffer response = new StringBuffer();
		String inputLine;
		while ((inputLine = in.readLine()) != null) {
			response.append(inputLine);
		}
		in.close();

		String xmlOut = response.toString();

		connection.disconnect();
		return (String) xstream.fromXML(xmlOut);

	}

	/**
	 * List content of a folder
	 * @param absPath
	 * @return
	 * @throws Exception
	 */
	@SuppressWarnings("unchecked")
	public static Map<String, Boolean> listFolder(String absPath) throws Exception {

		System.out.println("Calling servlet list folder " + absPath);
		XStream xstream = new XStream();
		String xmlOut = null;
		Map<String, Boolean> list = null;
		try{
			String uri = Config.URL_REPOSITORY + "/get/ListFolder?" + getCredentials() + "&login=" + Config.LOGIN + "&absPath=" + URLEncoder.encode(absPath, "UTF-8");
			//		System.out.println(uri);
			URL url = new URL(uri);
			HttpURLConnection connection = (HttpURLConnection) url.openConnection();
			connection.setRequestMethod("GET");
			connection.setRequestProperty("Accept", "application/xml");

			int responseCode = connection.getResponseCode();
			//		System.out.println("\nSending 'GET' request to URL : " + uri);
			System.out.println("Response Code : " + responseCode);



			BufferedReader in = new BufferedReader(
					new InputStreamReader(connection.getInputStream()));

			StringBuffer response = new StringBuffer();
			String inputLine;
			while ((inputLine = in.readLine()) != null) {
				response.append(inputLine);
			}
			in.close();

			xmlOut = response.toString();

			connection.disconnect();

			list = (Map<String, Boolean>) xstream.fromXML(xmlOut);

		} catch (ClassCastException e) {
			throw new Exception(e.getMessage());
		} 

		return list;

	}


}

==> home-library-ftpclient-1.0.0-20160711.161834-20-sources.jar: org/gcube/common/homelibrary/client/servlet/Servlets.java <==
package org.gcube.common.homelibrary.client.servlet;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;
import java.util.List;
import java.util.Map;

import org.gcube.common.homelibrary.client.util.Config;
import org.gcube.common.homelibrary.client.util.MultipartUtility;

import com.thoughtworks.xstream.XStream;

public class Servlets {

	/**
	 * Get jackrabbit credentials
	 * @return a string with credentials
	 */
	public static String getCredentials() {
		String credentials = "adminId=" + Config.USERNAME + "&adminPassword=" + Config.PASSWORD;
		return credentials;
	}


	/**
	 * Delete files or folder
	 * @param absPath absolute path of the item to delete
	 * @return true if the file/folder has been deleted
	 * @throws Exception
	 */
	public static Boolean delete(String absPath) throws Exception{
		XStream xstream = null;
		String xmlOut = null;
		Boolean flag = false;
		try{
			String uri = Config.URL_REPOSITORY + "/post/Delete";
			String urlParameters = getCredentials() + "&login=" + Config.LOGIN + "&scope=" + Config.SCOPE + "&serviceName=" + Config.SERVICE_NAME+ "&absPath=" +  URLEncoder.encode(absPath, "UTF-8") ;
			URL url = new URL(uri);
			HttpURLConnection connection = (HttpURLConnection) url.openConnection();
			connection.setRequestMethod("POST");
			connection.setRequestProperty("Accept", "application/xml");

			// Send post request
			connection.setDoOutput(true);
			DataOutputStream wr = new DataOutputStream(connection.getOutputStream());
			wr.writeBytes(urlParameters);
			wr.flush();
			wr.close();

			int responseCode = connection.getResponseCode();
			//			System.out.println("\nSending 'POST' request to URL : " + url);
			//			System.out.println("Post parameters : " + urlParameters);
			System.out.println("Response Code : " + responseCode);

			xstream = new XStream();

			BufferedReader in = new BufferedReader(
					new InputStreamReader(connection.getInputStream()));

			StringBuffer response = new StringBuffer();
			String inputLine;
			while ((inputLine = in.readLine()) != null) {
				response.append(inputLine);
			}
			in.close();

			xmlOut = response.toString();

			connection.disconnect();


			flag = (Boolean) xstream.fromXML(xmlOut);


		} catch (ClassCastException e) {

			throw new Exception(e.getMessage());
		} 

		return flag;

	}
	
	
	
	/**
	 * Save a file
	 * @param in
	 * @param name
	 * @param description
	 * @param parentPath
	 * @param mimetype
	 * @param size
	 * @return
	 * @throws Exception
	 */
	public static String uploadFile(byte[] in, String name, String description, String parentPath, String mimetype, long size) throws Exception {
		XStream xstream = new XStream();

		System.out.println("Upload File " + name);

		String uri = Config.HTTP_URL_REPOSITORY + "/post/Upload?login=" + Config.LOGIN + "&scope=" + Config.SCOPE + "&serviceName=" + Config.SERVICE_NAME+ "&name=" + name+ "&description=" + URLEncoder.encode(description, "UTF-8") + "&parentPath=" + URLEncoder.encode(parentPath, "UTF-8") + "&mimetype=" + mimetype + "&size=" + String.valueOf(size);
		
		System.out.println(uri);
		URL url = new URL(uri);
		HttpURLConnection connection = (HttpURLConnection)url.openConnection();
		connection.setDoInput(true);
		connection.setDoOutput(true);
		connection.setUseCaches(false);
		connection.setRequestProperty("Content-Type", "image/jpeg");
		connection.setRequestMethod("POST");
		
		// Write file to response.
	    OutputStream output = connection.getOutputStream();
	    output.write(in);
	    output.close();
	    
		BufferedReader r = new BufferedReader(new  InputStreamReader(connection.getInputStream()));

		StringBuffer response = new StringBuffer();
		String inputLine;
		while ((inputLine = r.readLine()) != null) {
			response.append(inputLine);
		}

		String xmlOut = response.toString();
		return (String) xstream.fromXML(xmlOut);
	}



	/**
	 * Save a file
	 * @param path
	 * @param name
	 * @param description
	 * @param parentPath
	 * @return
	 * @throws Exception
	 */
	public static String uploadFile(File file, String name, String description, String parentPath, String charset) throws Exception {

		//		System.out.println("Save file " + name +  " in " + parentPath);

		StringBuffer res = new StringBuffer();
		XStream xstream = new XStream();
		try {

			if (name==null)
				name = file.getName();

			//			File uploadFile1 = new File(path);

			String requestURL = Config.HTTP_URL_REPOSITORY + "/post/UploadFile?" + getCredentials() + "&login=" + Config.LOGIN + "&scope=" + Config.SCOPE + "&filename=" + file.getName()+ "&serviceName=" + Config.SERVICE_NAME+ "&name=" + name+ "&description=" + URLEncoder.encode(description, "UTF-8") + "&parentPath=" + URLEncoder.encode(parentPath, "UTF-8");
			MultipartUtility multipart = new MultipartUtility(requestURL, charset);

			multipart.addHeaderField("User-Agent", "CodeJava");
			multipart.addHeaderField("Test-Header", "Header-Value");

			multipart.addFormField("description", "upload file");
			//			multipart.addFormField("keywords", "Java,upload");

			multipart.addFilePart("fileUpload", file);
			//	            multipart.addFilePart("fileUpload", uploadFile2);

			List<String> response = multipart.finish();

			for (String line : response) {
				res.append(line);
			}

		} catch (IOException e) {
			throw new Exception(e.getMessage());
		} 

		return (String) xstream.fromXML(res.toString());
	}


	/**
	 * Create a folder
	 * @param name
	 * @param description
	 * @param parentPath
	 * @return
	 * @throws Exception
	 */
	public static String createFolder(String name, String description,
			String parentPath) throws Exception {

		System.out.println("Create Folder " + name);
		String uri = Config.URL_REPOSITORY + "/post/CreateFolder";
		String urlParameters = getCredentials() + "&login=" + Config.LOGIN + "&name=" + name+ "&description=" + URLEncoder.encode(description, "UTF-8") + "&parentPath=" + URLEncoder.encode(parentPath, "UTF-8");
		URL url = new URL(uri);
		HttpURLConnection connection = (HttpURLConnection) url.openConnection();
		connection.setRequestMethod("POST");
		connection.setRequestProperty("Accept", "application/xml");

		// Send post request
		connection.setDoOutput(true);
		DataOutputStream wr = new DataOutputStream(connection.getOutputStream());
		wr.writeBytes(urlParameters);
		wr.flush();
		wr.close();

		int responseCode = connection.getResponseCode();
		//		System.out.println("\nSending 'POST' request to URL : " + url);
		//		System.out.println("Post parameters : " + urlParameters);
		System.out.println("Response Code : " + responseCode);

		XStream xstream = new XStream();

		BufferedReader in = new BufferedReader(
				new InputStreamReader(connection.getInputStream()));

		StringBuffer response = new StringBuffer();
		String inputLine;
		while ((inputLine = in.readLine()) != null) {
			response.append(inputLine);
		}
		in.close();

		String xmlOut = response.toString();

		connection.disconnect();
		return (String) xstream.fromXML(xmlOut);

	}

	/**
	 * List content of a folder
	 * @param absPath
	 * @return
	 * @throws Exception
	 */
	@SuppressWarnings("unchecked")
	public static Map<String, Boolean> listFolder(String absPath) throws Exception {

		System.out.println("Calling servlet list folder " + absPath);
		XStream xstream = new XStream();
		String xmlOut = null;
		Map<String, Boolean> list = null;
		try{
			String uri = Config.URL_REPOSITORY + "/get/ListFolder?" + getCredentials() + "&login=" + Config.LOGIN + "&absPath=" + URLEncoder.encode(absPath, "UTF-8");
			//		System.out.println(uri);
			URL url = new URL(uri);
			HttpURLConnection connection = (HttpURLConnection) url.openConnection();
			connection.setRequestMethod("GET");
			connection.setRequestProperty("Accept", "application/xml");

			int responseCode = connection.getResponseCode();
			//		System.out.println("\nSending 'GET' request to URL : " + uri);
			System.out.println("Response Code : " + responseCode);



			BufferedReader in = new BufferedReader(
					new InputStreamReader(connection.getInputStream()));

			StringBuffer response = new StringBuffer();
			String inputLine;
			while ((inputLine = in.readLine()) != null) {
				response.append(inputLine);
			}
			in.close();

			xmlOut = response.toString();

			connection.disconnect();

			list = (Map<String, Boolean>) xstream.fromXML(xmlOut);

		} catch (ClassCastException e) {
			throw new Exception(e.getMessage());
		} 

		return list;

	}


}
